@@ -44,6 +44,7 @@
 #' }
 #' @import redland
 #' @import uuid
+#' @import XML
 #' @section Methods:
 #' \itemize{
 #'  \item{\code{\link[=ResourceMap-initialize]{initialize}}}{: Initialize a ResourceMap object.}
@@ -70,7 +71,7 @@ setClass("ResourceMap", slots = c(relations = "data.frame",
 #' @return the ResourceMap object
 #' @seealso \code{\link{ResourceMap-class}}
 #' @export
-setMethod("initialize", "ResourceMap", function(.Object, id = as.character(NA)) {
+setMethod("initialize", "ResourceMap", function(.Object, id = NA_character_) {
   .Object@relations <- data.frame()
   .Object@world   <- new("World")
   .Object@storage <- new("Storage", .Object@world, "hashes", name="", options="hash-type='memory'")
@@ -121,8 +122,8 @@ setGeneric("createFromTriples", function(x, ...) { standardGeneric("createFromTr
 #' @param ... (Additional parameters)
 #' @export
 setMethod("createFromTriples", signature("ResourceMap"), function(x, relations, identifiers, 
-                                                                  resolveURI=as.character(NA), externalIdentifiers=list(), 
-                                                                  creator=as.character(NA), ...) {
+                                                                  resolveURI=NA_character_, externalIdentifiers=list(), 
+                                                                  creator=NA_character_, ...) {
   stopifnot(is.data.frame(relations))
   stopifnot(all(is.character(identifiers)))
   
@@ -132,6 +133,7 @@ setMethod("createFromTriples", signature("ResourceMap"), function(x, relations,
   D1ResolveURI <- "https://cn.dataone.org/cn/v2/resolve"
   
   if(is.na(creator)) creator <- "DataONE R Client"
+  creatorFound <- FALSE
   
   if(is.na(resolveURI)) {
     pkgResolveURI <- D1ResolveURI
@@ -156,7 +158,7 @@ setMethod("createFromTriples", signature("ResourceMap"), function(x, relations,
   
   # Add each triple from the input data.frame into the Redland RDF model.
   if(nrow(relations) > 0) {
-      for(i in 1:nrow(relations)) {
+      for(i in seq_len(nrow(relations))) {
           triple <- relations[i,]
           subjectId <- triple[['subject']]
           objectId <- triple[['object']]
@@ -205,7 +207,7 @@ setMethod("createFromTriples", signature("ResourceMap"), function(x, relations,
     }
     
     # Add the Dublic Core identifier relation for each object added to the data package
-    statement <- new("Statement", x@world, subject=URIid, predicate=DCidentifier, object=id, objectType="literal", datatype_uri=xsdString)
+    statement <- new("Statement", x@world, subject=URIid, predicate=DCTERMSidentifier, object=id, objectType="literal", datatype_uri=xsdString)
     addStatement(x@model, statement)
     
     # Add triples for each object that is aggregated
@@ -224,7 +226,7 @@ setMethod("createFromTriples", signature("ResourceMap"), function(x, relations,
         URIid <- id
     }
     # Add the Dublic Core identifier relation for each object added to the data package
-    statement <- new("Statement", x@world, subject=URIid, predicate=DCidentifier, object=id, objectType="literal", datatype_uri=xsdString)
+    statement <- new("Statement", x@world, subject=URIid, predicate=DCTERMSidentifier, object=id, objectType="literal", datatype_uri=xsdString)
     addStatement(x@model, statement)
   }
 
@@ -234,10 +236,10 @@ setMethod("createFromTriples", signature("ResourceMap"), function(x, relations,
   
   # Not sure if this is needed by D1 to parse resourceMap
   #currentTime <- format(Sys.time(), "%Y-%m-%dT%H:%M:%S.000%z")
-  #statement <- new("Statement", x@world, subject=resMapURI, predicate=DCmodified, object=currentTime, objectType="literal", datatype_uri=xsdDateTimeURI)
+  #statement <- new("Statement", x@world, subject=resMapURI, predicate=DCTERMSmodified, object=currentTime, objectType="literal", datatype_uri=xsdDateTimeURI)
     
   # Add the identifier for the ResourceMap
-  statement <- new("Statement", x@world, subject=resMapURI, predicate=DCidentifier, object=URLdecode(x@id),
+  statement <- new("Statement", x@world, subject=resMapURI, predicate=DCTERMSidentifier, object=URLdecode(x@id),
                    objectType="literal", datatype_uri=xsdString)
   
   addStatement(x@model, statement)
@@ -252,28 +254,34 @@ setMethod("createFromTriples", signature("ResourceMap"), function(x, relations,
   statement <- new("Statement", x@world, subject=resMapURI, predicate=OREdescribes, object=aggregationId)
   addStatement(x@model, statement)
   
+  # This triple isn't strictly required by the ORE spec. 
+  #statement <- new("Statement", x@world, subject=aggregationId, predicate=OREisDescribedBy, object=resMapURI)
+  #addStatement(x@model, statement)
+  
   # Add a resource map creator (an Agent)
   # For example: 
   # _:r1495819159r74422r1 http://www.w3.org/1999/02/22-rdf-syntax-ns#type http://purl.org/dc/terms/Agent
   # _:r1495819159r74422r1 http://xmlns.com/foaf/0.1/name> "DataONE Java Client Library"^^<http://www.w3.org/2001/XMLSchema#string>
   # https://cn.dataone.org/cn/v1/resolve/resourceMap_karakoenig.46.6 http://purl.org/dc/elements/1.1/creator _:r1495819159r74422r1
   
-  # Always add a creator
+  # Use the previous creaor id if found, otherwise create a new one.
   
-  creatorBlankNodeId <- sprintf("_%s", UUIDgenerate())
-  statement <- new("Statement", x@world, subject=creatorBlankNodeId, predicate=RDFtype, object=DCagent,
-                   subjectType="blank")
-  addStatement(x@model, statement)
-  statement <- new("Statement", x@world, subject=creatorBlankNodeId, predicate=foafName, object=creator,
-                   subjectType="blank", objectType="literal", datatype_uri=xsdString)
-  addStatement(x@model, statement)
-  statement <- new("Statement", x@world, subject=resMapURI, predicate=DCcreator, object=creatorBlankNodeId,
-                   objectType="blank")
-  addStatement(x@model, statement)
+  if(!creatorFound) {
+    creatorBlankNodeId <- sprintf("_%s", UUIDgenerate())
+    statement <- new("Statement", x@world, subject=creatorBlankNodeId, predicate=RDFtype, object=DCTERMSagent,
+                     subjectType="blank")
+    addStatement(x@model, statement)
+    statement <- new("Statement", x@world, subject=creatorBlankNodeId, predicate=foafName, object=creator,
+                     subjectType="blank", objectType="literal", datatype_uri=xsdString)
+    addStatement(x@model, statement)
+    statement <- new("Statement", x@world, subject=resMapURI, predicate=DCTERMScreator, object=creatorBlankNodeId,
+                     objectType="blank")
+    addStatement(x@model, statement)
+  }
   
   # Add modification time, required by ORE Resource Map specification
   now <- format.POSIXct(Sys.time(), format="%FT%H:%M:%SZ", tz="GMT", usetz=FALSE)
-  statement <- new("Statement", x@world, subject=resMapURI, predicate=DCmodified, object=now, 
+  statement <- new("Statement", x@world, subject=resMapURI, predicate=DCTERMSmodified, object=now, 
                    objectType="literal", datatype_uri=xsdDateTime)
   addStatement(x@model, statement)
 
@@ -318,20 +326,32 @@ setMethod("serializeRDF", signature("ResourceMap"), function(x,
                                                              mimeType="application/rdf+xml", 
                                                              namespaces=data.frame(namespace=character(), 
                                                              prefix=character(), stringsAsFactors=FALSE),
-                                                             syntaxURI=as.character(NA)) {
+                                                             syntaxURI=NA_character_) {
   
   # Define default namespaces used by DataONE ORE Resource Maps,
-  defaultNS <- data.frame(namespace=character(), prefix=character(), stringsAsFactors=FALSE)
-  defaultNS <- rbind(defaultNS, data.frame(namespace="http://www.w3.org/1999/02/22-rdf-syntax-ns#", prefix="rdf", row.names = NULL, stringsAsFactors = FALSE))
-  defaultNS <- rbind(defaultNS, data.frame(namespace="http://www.w3.org/2001/XMLSchema#", prefix="xsd", row.names = NULL, stringsAsFactors = FALSE))
-  defaultNS <- rbind(defaultNS, data.frame(namespace="http://www.w3.org/2000/01/rdf-schema#", prefix="rdfs", row.names = NULL, stringsAsFactors = FALSE))
-  defaultNS <- rbind(defaultNS, data.frame(namespace="http://www.w3.org/ns/prov#", prefix="prov", row.names = NULL, stringsAsFactors = FALSE))
-  defaultNS <- rbind(defaultNS, data.frame(namespace="http://purl.dataone.org/provone/2015/01/15/ontology#", prefix="provone", row.names = NULL, stringsAsFactors = FALSE))
-  defaultNS <- rbind(defaultNS, data.frame(namespace="http://purl.org/dc/elements/1.1/", prefix="dc", row.names = NULL, stringsAsFactors = FALSE))
-  defaultNS <- rbind(defaultNS, data.frame(namespace="http://purl.org/dc/terms/", prefix="dcterms", row.names = NULL, stringsAsFactors = FALSE))
-  defaultNS <- rbind(defaultNS, data.frame(namespace="http://xmlns.com/foaf/0.1/", prefix="foaf", row.names = NULL, stringsAsFactors = FALSE))
-  defaultNS <- rbind(defaultNS, data.frame(namespace="http://www.openarchives.org/ore/terms/", prefix="ore", row.names = NULL, stringsAsFactors = FALSE))
-  defaultNS <- rbind(defaultNS, data.frame(namespace="http://purl.org/spar/cito/", prefix="cito", row.names = NULL, stringsAsFactors = FALSE))
+  namespace_vector <- c("http://www.w3.org/1999/02/22-rdf-syntax-ns#",
+                        "http://www.w3.org/2001/XMLSchema#",
+                        "http://www.w3.org/2000/01/rdf-schema#",
+                        "http://www.w3.org/ns/prov#",
+                        "http://purl.dataone.org/provone/2015/01/15/ontology#",
+                        "http://purl.org/dc/elements/1.1/",
+                        "http://purl.org/dc/terms/",
+                        "http://xmlns.com/foaf/0.1/",
+                        "http://www.openarchives.org/ore/terms/",
+                        "http://purl.org/spar/cito/")
+  
+  prefixes <- c("rdf",
+                "xsd",
+                "rdfs",
+                "prov",
+                "provone",
+                "dc",
+                "dcterms",
+                "foaf",
+                "ore",
+                "cito")
+  
+  defaultNS <- data.frame(namespace = namespace_vector, prefix = prefixes, stringsAsFactors=FALSE)
   
   # Merge the default namespaces with the namespaces passed in
   namespaces <- merge(defaultNS, namespaces, all.x=TRUE, all.y=TRUE)
@@ -339,7 +359,7 @@ setMethod("serializeRDF", signature("ResourceMap"), function(x,
 
   # Add default and additional namespaces to the serializer
   if(nrow(namespaces) > 0) {
-      for(i in 1:nrow(namespaces)) {
+      for(i in seq_len(nrow(namespaces))) {
           thisNamespace <- namespaces[i,]
           namespace <- as.character(thisNamespace['namespace'])
           prefix <- as.character(thisNamespace['prefix'])
@@ -425,115 +445,127 @@ setMethod("getTriples", "ResourceMap", function(x, filter=TRUE, identifiers=list
   
     relations <- data.frame(row.names=NULL, stringsAsFactors=F)
     
-    # Get the aggregation URI for use in qualifying certain relationships that we wan to skip.
-    # s: <https://cn-stage-2.test.dataone.org/cn/v2/resolve/urn:uuid:63ac03cb-6fea-4013-8fc7-25d2ff5cc8cb#aggregation> 
-    # p: <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> i
-    # o: <http://www.openarchives.org/ore/terms/Aggregation> 
-   
-    # s: <https://cn-stage-2.test.dataone.org/cn/v2/resolve/urn:uuid:63ac03cb-6fea-4013-8fc7-25d2ff5cc8cb> 
-    # p: <http://purl.org/dc/terms/identifier> 
-    # o: "urn:uuid:63ac03cb-6fea-4013-8fc7-25d2ff5cc8cb"^^<http://www.w3.org/2001/XMLSchema#string>
-    
+
+    # See ./inst/extdata/sparql-query-result.xml to see an example SPARQL qeury that
+    # getTriples can parse.
     parser <- new("Parser", x@world)
     # Query the RDF model with a SPARQL query that should return all triples
     queryString <- 'SELECT ?s ?p ?o WHERE { ?s ?p ?o . }'
     query <- new("Query", x@world, queryString, base_uri=NULL, query_language="sparql", query_uri=NULL)
-    queryResult <- executeQuery(query, x@model)
+
+    # Create a data frame from the results
+    resultStr <- redland::getResults(query, x@model, "rdfxml")
+    doc <- xmlInternalTreeParse(resultStr, asText=TRUE)
+    rdfStmtNodes <- getNodeSet(doc, "//rs:solution/rdf:Description")
     
     # Retrieve query results and check the actual result count against the expected count
-    result <- getNextResult(queryResult)
-    first <- TRUE
     # Remove a creator id if filtering and it is found
-    creatorId <- as.character(NA)
+    creatorId <- NA_character_
     creatorFound <- FALSE
-    while(!is.null(result)) {
-        # Can't get next result at the end of the loop because 'next' is used.
-        if(first) first <- FALSE else result <- getNextResult(queryResult)
-        if(is.null(result)) break
-        subject <- result$s
-        predicate <- result$p
-        object <- result$o
-        what <- result$d
-        objectType <- as.character(NA)
-        subjectType <- as.character(NA)
-        dataTypeURI <- as.character(NA)
-        #cat(sprintf("s: %s p: %s o: %s\n", subject, predicate, object))
-        # Remove leading '<' and trailing '>" from the result. The result is returned as
-        # RDF NTriples, so annotations to the terms denotes the type. (see https://www.w3.org/TR/n-triples/)
-        if(grepl("^<.*>$", subject, perl=TRUE))   {
-            subject   <- gsub("^<", "", subject, perl=TRUE)
-            subject   <- gsub(">$", "", subject, perl=TRUE)
-            subjectType <- "uri"
-        } else if(grepl("^_:", subject, perl=TRUE)) {
-            # Remove the colon from the blank node identifier, as this will be an illigal XML name
-            # when the relationships are serialized to RDF/XML
-            subject <- gsub("^_:", "_", subject, perl=TRUE)
-            subjectType <- "blank"
-        } else {
-            # Subject type can only be 'uri' or 'blank'. If the subject is not surrounded by
-            # '<', '>' and doesn't start with the N-Triples '_:', then it is some non-standard blank
-            # node name.
-            subjectType <- "blank"
-        }
+    
+    subject <- NA_character_
+    predicate <- NA_character_
+    object <- NA_character_
+    objectType <- NA_character_
+    subjectType <- NA_character_
+    dataTypeURI <- NA_character_
+    
+    # Loop over the RDF statements of the SPARQL query result
+    for (stmt in rdfStmtNodes) {
+        bindings <- xmlChildren(stmt)
         
-        # The predicate is always a 'uri'
-        if(grepl("^<.*>$", predicate, perl=TRUE)) {
-            predicate <- gsub("^<", "", predicate, perl=TRUE)
-            predicate <- gsub(">$", "", predicate, perl=TRUE)
-        } else {
-            warning(sprintf("Invalid predicate %s, not valid N-Triples value.", predicate))
-        }
+        subject <- NA_character_
+        predicate <- NA_character_
+        object <- NA_character_
+        objectType <- NA_character_
+        subjectType <- NA_character_ 
+        dataTypeURI <- NA_character_
         
-        # Parse object and determine its type. The object may be appended with language designation
-        # e.g. "@en" or a data type, e.g. "^^<xsd:dateTime>"
-        if(grepl("^<", object, perl=TRUE)) {
-            object <- gsub("^<", "", object, perl=TRUE)
-            object <- gsub(">$", "", object, perl=TRUE)
-            objectType <- "uri"
-        } else if(grepl("^\"", object, perl=TRUE)) {
-            # The object might contain a data type appended to it with the string "^^" separating
-            # the object and the data type
-            if(grepl("^^", object, fixed=TRUE)) {
-                strResult <- strsplit(object, '^^', fixed=TRUE)
-                object <- strResult[[1]][[1]]
-                dataTypeURI <- strResult[[1]][[2]]
-                #cat(sprintf("object: %s\n objectType: %s\n", object, objectType))
-                dataTypeURI <- gsub("^<", "", dataTypeURI, perl=TRUE)
-                dataTypeURI <- gsub(">$", "", dataTypeURI, perl=TRUE)
+        # Loop over the bindings, i.e. subject, predicate, object
+        for (binding in bindings) {
+            nodeName <- xmlName(binding)
+            nodeValue <- NA_character_
+            nodeType <- NA_character_
+            RDFnodeType <- NA_character_
+            # Loop over attributes for this binding object (RDF node) 
+            for (node in xmlChildren(binding[['Description']])) {
+                
+                # Need to set subject, predicate, object, subjectType, objectType, dataTypeURI
+                name <- xmlName(node)
+                # The 'value' of the node can either be in an attribute (e.g. 'rdf:nodeId="_:1234") or
+                # in the xml element value`
+                value <- xmlValue(node)
+                attrs <- xmlAttrs(node)
+                
+                if(grepl("value", name)) {
+                    if (any(grepl("resource", names(attrs)))) {
+                        RDFnodeType <- "uri"
+                        nodeValue <- attrs[["resource"]]
+                    } else if (any(grepl("nodeID", names(attrs)))) {
+                        RDFnodeType <- "blank"
+                        nodeValue <- attrs[["nodeID"]]
+                    } else if (any(grepl("datatype", names(attrs)))) {
+                        RDFnodeType <- "literal"
+                        nodeValue <- value
+                        dataTypeURI <- attrs[["datatype"]]
+                    } else {
+                        RDFnodeType <- "literal"
+                        nodeValue <- value
+                    }
+                } else if (grepl("variable", name)) {
+                    # The variables from the SPARQL query
+                    if(value == "s") {
+                       nodeType <- "subject" 
+                    } else if (value == "o") {
+                        nodeType <- "object"
+                    } else if (value == "p") {
+                        nodeType <- "predicate"
+                    } else {
+                        warning("Unknown RDF node type: %s\n", value)
+                    }
+                    
+                }
+            }
+            
+            # All the info for this triple should now be set, sa assign the
+            # subject, predicate, object. Note that 'dataTypeURI' should also be
+            # set, if found in the triple
+            if(nodeType == "subject") {
+                subject <- nodeValue
+                subjectType <- RDFnodeType
+            } else if (nodeType == "object") {
+                object <- nodeValue
+                objectType <- RDFnodeType
+            } else if (nodeType == "predicate") {
+                predicate <- nodeValue
+            } else {
+                warning("Cannot determine RDF node type for node: %s\n", name)
             }
-            object <- gsub('^"', "", object, perl=TRUE)
-            object <- gsub('"$', "", object, perl=TRUE)
-            objectType <- "literal"
-        } else if(grepl("^_:", object, perl=TRUE)) {
-            object <- gsub("^_:", "_", object, perl=TRUE)
-            objectType <- "blank"
-        } else {
-            # Object type can be 'uri', 'blank' or 'literal'. If the object is not surrounded by
-            # '<', '>' or '"', and doesn't start with the N-Triples '_:', then it is some non-standard blank
-            # node name.
-            objectType <- "blank"
         }
-
+        
+        #cat(sprintf("s: %s p: %s o: %s\n", subject, predicate, object))
+        
         # Filter DataONE packaging statements that may have been inserted during 'createFromTriples'
         # Filtering this way is much easier than filtering in SPARQL!
         # This method of filtering assumes that the namespaces have been expanded, which appears
-        # to happen during hthe redland parsing. This is advantageous, as then we don't need
+        # to happen during the redland parsing. This is advantageous, as then we don't need
         # to determine what namespaces existing in the resource map, and any namespace prefix
         # to uri mapping that was in effect. Also, the filtering can use the expanded names.
+        
         if(filter) { 
             if((predicate == DCtitle) && (object == "DataONE Aggregation")) {
                 next
             } else if((predicate == RDFtype) && (object == OREresourceMap)) {
                 next
-            } else if(object == DCagent) {
+            } else if(object == DCTERMSagent) {
                 creatorId <- subject
                 next
-            } else if(predicate == DCcreator) {
+            } else if(predicate == DCTERMScreator) {
                 creatorId <- subject
                 next
-            } else if(predicate == DCmodified) {
+            } else if(predicate == DCTERMSmodified) {
                 next
-            } else if(predicate == DCidentifier) {
+            } else if(predicate == DCTERMSidentifier) {
                 # Filter the dcterms:identifier statement for package ids
                 id <- checkIdMatch(object, pattern='%s$', identifiers)
                 if(!is.na(id))  next
@@ -608,8 +640,6 @@ setMethod("getTriples", "ResourceMap", function(x, filter=TRUE, identifiers=list
     rm(parser)
     freeQuery(query)
     rm(query)
-    freeQueryResults(queryResult)
-    rm(queryResult)
     
     return(base::unique(relations))
   
@@ -623,7 +653,7 @@ checkIdMatch <- function(checkStr, pattern, identifiers) {
     if(length(identifiers) > 0) {
         checkStr <- trimws(checkStr, which="both")
         checkStrDecoded <- URLdecode(checkStr)
-        for(nId in 1:length(identifiers)) {
+        for(nId in seq_along(identifiers)) {
             thisId <- trimws(identifiers[[nId]], which="both")
             thisIdDecoded <- URLdecode(thisId)
             thisIdEncoded <- URLencode(thisId, reserved=TRUE, repeated=TRUE)
@@ -645,5 +675,5 @@ checkIdMatch <- function(checkStr, pattern, identifiers) {
             }
         }
     }
-    return(as.character(NA))
+    return(NA_character_)
 }
